/*----------------------------------------------------------------------------
*         ATMEL Microcontroller Software Support  -  ROUSSET  -
*----------------------------------------------------------------------------
* The software is delivered "AS IS" without warranty or condition of any
* kind, either express, implied or statutory. This includes without
* limitation any warranty or condition with respect to merchantability or
* fitness for any particular purpose, or against the infringements of
* intellectual property rights of others.
*----------------------------------------------------------------------------
* File Name           : Board.h
* Object              : AT91SAM7S Evaluation Board Features Definition File.
*
* Creation            : JPP   16/Jun/2004
*  1.1 14/Oct/05 JPP  : Change MCK
*----------------------------------------------------------------------------
*/
#ifndef Board_h
#define Board_h

#include "AT91SAM7S64.h"
//mtA:
// #define __inline inline
#define __inline static inline
//mtE
#include "lib_AT91SAM7S64.h"

//mtA
//#define __ramfunc __attribute__ ((long_call, section (".fastrun")))
#define __ramfunc
//mtE

#define true	-1
#define false	0

/*-------------------------------*/
/* SAM7Board Memories Definition */
/*-------------------------------*/
// The AT91SAM7S64 embeds a 16-Kbyte SRAM bank, and 64 K-Byte Flash

#define  INT_SARM           0x00200000
#define  INT_SARM_REMAP	    0x00000000

#define  INT_FLASH          0x00000000
#define  INT_FLASH_REMAP    0x01000000

#define  FLASH_PAGE_NB		512
#define  FLASH_PAGE_SIZE	128

/*-----------------*/
/* Leds Definition */
/*-----------------*/
/*                                 PIO   Flash    PA    PB   PIN */
////#define LED1            (1<<18)	/* PA18 / PGMEN0 & PWM0 TIOA0  48 */
////#define LED2            (1<<17)	/* PA17 / PGMEN1 & PWM1 TIOB0  47 */
//#define LED3            (1<<2)	/* PA2          & PWM2 SCK0   44 */
//#define LED4            (1<<3)	/* PA3          & TWD  NPCS3  43 */
//#define LED5			(1<<28) /* PA25							*/
//#define LED7			(1<<27)  	/* PA26							*/
////#define NB_LEB			2

////#define LED_MASK        (LED1|LED2)

//----------------------------------
// UART Definition
//----------------------------------
#define D0				(1<<0)						// PA0   
#define D1				(1<<1)						// PA1  
#define D2				(1<<2)						// PA2 
#define D3				(1<<3)						// PA3   
#define D4				(1<<4)						// PA4   
#define D5				(1<<5)						// PA5 
#define D6				(1<<6)						// PA6   
#define D7				(1<<7)						// PA7  
#define A0				(1<<8)						// PA8
#define A1				(1<<9)						// PA9
#define A2				(1<<10)						// PA10
#define CS1				(1<<11)						// PA11
#define CS2				(1<<12)						// PA12
#define read			(1<<13)						// PA13 3.3
#define write			(1<<14)						// PA14	3.3
#define interrupt_A		(1<<15)						// PA15   0
#define interrupt_B		(1<<16)						// PA16   0
#define interrupt_C		(1<<18)						// PA18   0
#define interrupt_D		(1<<19)						// PA19   0
#define BUS_DONNEE		(D7|D6|D5|D4|D3|D2|D1|D0)
#define BUS_ADDRESS		(A2|A1|A0)
#define CS_mask			(CS2|CS1)
#define UART_mask		(BUS_DONNEE|CS_mask|read|write|BUS_ADDRESS)
#define INTERRUPT_mask	(interrupt_A|interrupt_B|interrupt_C|interrupt_D)

//----------------------------------
//	CAN Definition
//----------------------------------
#define HP_4			(1<<17)						// PA17   
#define HP_3			(1<<AD6)					// AD6
#define HP_2			(1<<AD5)					// AD5
#define HP_1			(1<<AD4)					// AD4  
#define HP_mask			(HP_1|HP_2|HP_3|HP_4)

//----------------------------------
//	Input Definition
//----------------------------------
#define entree_1		(1<<29)							// PA29   
#define entree_2		(1<<30)							// PA30   
#define entree_3		(1<<31)							// PA31
#define entrees			(entree_1|entree_2|entree_3)

//----------------------------------
//	Output Definition
//----------------------------------

#define sortie_1		(1<<23)						// PA23   
#define sortie_2		(1<<24)						// PA24   
#define sortie_3		(1<<25)						// PA25   
#define sortie_4		(1<<26)						// PA29  
#define sortie_5		(1<<27)						// PA29   
#define sortie_6		(1<<28)						// PA29  
#define alim_Anso		(1<<20)						// PA20   
#define sorties			(sortie_1|sortie_2|sortie_3|sortie_4|sortie_5|sortie_6|alim_Anso)


/*-------------------------*/
/* Push Buttons Definition */
/*-------------------------*/
/*                                 PIO    Flash    PA    PB   PIN */
////#define SW1_MASK        (1<<19)	/* PA19 / PGMD7  & RK   FIQ     13 */
////#define SW2_MASK        (1<<20)	/* PA20 / PGMD8  & RF   IRQ0    16 */
//#define SW3_MASK        (1<<15)	/* PA15 / PGM3   & TF   TIOA1   20 */
////#define SW4_MASK        (1<<16)	/* PA16 */
////#define SW_MASK         (SW1_MASK|SW2_MASK|SW3_MASK|SW4_MASK)


////#define SW1 	(1<<19)	// PA19
////#define SW2 	(1<<20)	// PA20
//#define SW3 	(1<<15)	// PA15
////#define SW4 	(1<<16)	// PA16

/*------------------*/
/* USART Definition */
/*------------------*/
/* SUB-D 9 points J3 DBGU*/
//#define DBGU_RXD		AT91C_PA9_DRXD	  /* JP11 must be close */
//#define DBGU_TXD		AT91C_PA10_DTXD	  /* JP12 must be close */
#define AT91C_DBGU_BAUD	   115200   // Baud rate
//
#define US_RXD_PIN		AT91C_PA21_RXD1    /* JP9 must be close */
#define US_TXD_PIN		AT91C_PA22_TXD1    /* JP7 must be close */
//#define US_RTS_PIN		AT91C_PA7_RTS0    /* JP8 must be close */
//#define US_CTS_PIN		AT91C_PA8_CTS0    /* JP6 must be close */

/*--------------*/
/* Master Clock */
/*--------------*/

#define EXT_OC          18432000   // Exetrnal ocilator MAINCK
#define MCK             48054857   // MCK (PLLRC div by 2)
#define MCKKHz          (MCK/1000) //

#endif /* Board_h */
